Welcome to Store factory for simplekv's documentation!
======================================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   reference/index
   contributing
   authors
   releasenotes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

